@@ -69,6 +69,9 @@ impl Zig {
                 if arg.ends_with(".rlib") && arg.contains("liblibc-") {
                     return None;
                 }
+                if arg == "-lc" {
+                    return None;
+                }
             }
             Some(arg.to_string())
         };
@@ -229,7 +232,7 @@ fn write_linker_wrapper(path: &Path, command: &str, args: &str) -> Result<()> {
     } else {
         env::current_exe()?
     };
-    writeln!(&mut custom_linker_file, "#!/bin/bash")?;
+    writeln!(&mut custom_linker_file, "#!/usr/bin/env bash")?;
     writeln!(
         &mut custom_linker_file,
         "{} zig {} -- {} $@",
